//@line 4 "/builds/slave/tb-rel-c-beta-lx_rpk_6-0000000/l10n/ko/calendar/lightning-l10n.js"

//@line 6 "/builds/slave/tb-rel-c-beta-lx_rpk_6-0000000/l10n/ko/calendar/lightning-l10n.js"

//@line 9 "/builds/slave/tb-rel-c-beta-lx_rpk_6-0000000/l10n/ko/calendar/lightning-l10n.js"
pref("calendar.week.start", 0);

//@line 12 "/builds/slave/tb-rel-c-beta-lx_rpk_6-0000000/l10n/ko/calendar/lightning-l10n.js"
pref("calendar.week.d0sundaysoff", true);
pref("calendar.week.d1mondaysoff", false);
pref("calendar.week.d2tuesdaysoff", false);
pref("calendar.week.d3wednesdaysoff", false);
pref("calendar.week.d4thursdaysoff", false);
pref("calendar.week.d5fridaysoff", false);
pref("calendar.week.d6saturdaysoff", true);

pref("general.useragent.locale", "ko");

//@line 23 "/builds/slave/tb-rel-c-beta-lx_rpk_6-0000000/l10n/ko/calendar/lightning-l10n.js"
pref("calendar.categories.names", "기념일,생일,엄무,호출,손님,시합,고객,선호,진행 사항,선물,휴가,아이디어,논의 사항,기타,개인,프로젝트,공휴일,상태,납품,여행,방학");
